@@ -9,7 +9,7 @@ class Event:
     def unhandle(self, handler):
         try:
             self.handlers.remove(handler)
-        except (KeyError):
+        except KeyError:
             raise ValueError("Handler is not handling this event, so cannot unhandle it.")
         return self
 
