@@ -28,7 +28,7 @@ class TextBox(Control):
         self.close_keyboard_on_send = close_keyboard_on_send
 
     def get_state(self):
-        return self._state_str + f"{self.text}\n"
+        return self._control_hdr_str + f"{self.text}\n"
 
     @property
     def text(self):
@@ -37,7 +37,7 @@ class TextBox(Control):
     @text.setter
     def text(self, val):
         self._text = val
-        self.state_str = self._state_str + f"{self.text}\n"
+        self.state_str = self._control_hdr_str + f"{self.text}\n"
 
     @property
     def text_align(self) -> TextAlignment:
