@@ -16,7 +16,7 @@ class TCP():
     def get_state(self) -> str:
         return ""
 
-    def get_cfg(self, page_size_x, page_size_y):
+    def get_cfg(self, num_columns):
         cfg_str = "\tCFG\t" + self.msg_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
